@@ -250,50 +250,6 @@ std::string mcontrollist [] = {
     "@end","@end"
 };
 
-std::string commonlist [] = {
-    "","The common list is deprecated and will eventually be removed.",
-    "ON @",                     "enables the part/kit item/engine/insert etc,",
-    "OFF @",                    "disables as above",
-    "Volume <n> @",             "volume",
-    "Pan <n> @",                "panning position",
-    "VElocity <n> @",           "velocity sensing sensitivity",
-    "MIn <[s][n]> +",           "minimum MIDI note value (Last seen or 0-127)",
-    "MAx <[s][n]> +",           "maximum MIDI note value (Last seen or 0-127)",
-    "DETune Fine <n> *",        "fine frequency",
-    "DETune Coarse <n> *",      "coarse stepped frequency",
-    "DETune Type <s> *",        "type of coarse stepping", "","(DEFault, L35, L10, E100, E1200)",
-    "OCTave <n> *",             "shift octaves up or down",
-    "FIXed <s> *-add",          "set base frequency to 440Hz (ON, {other})",
-    "EQUal <n> *-add",          "equal temper variation",
-    "BENd Adjust <n>  *-add",   "pitch bend range",
-    "BENd Offset <n>  *-add",   "pitch bend shift",
-    "STEreo <s> *-voice",       "ON, {other}",
-    "DEPop <n> &",              "initial attack slope",
-    "PUnch Power <n> &",        "attack boost amplitude",
-    "PUnch Duration <n> &",     "attack boost time",
-    "PUnch Stretch <n> &",      "attack boost extend",
-    "PUnch Velocity <n> &",     "attack boost velocity sensitivity",
-    "OVertone Position <s> #",  "relationship to fundamental",
-    "","(HArmonic, SIne, POwer, SHift, UShift, LShift, UPower, LPower)",
-    "OVertone First <n> #",     "degree of first parameter",
-    "OVertone Second <n> #",    "degree of second parameter",
-    "OVertone Harmonic <n> #",  "amount harmonics are forced",
-    "LFO ... *-sub",            "enter LFO insert context",
-    "FILter ... *",             "enter Filter insert context",
-    "ENVelope ... *",           "enter Envelope insert context",
-    "","",
-    "@",                        "exists in all part contexts",
-    "+",                        "part and kit mode controls",
-    "*",                        "Add, Sub, Pad and AddVoice controls",
-    "*-add",                    "not AddSynth",
-    "*-sub",                    "not SubSynth",
-    "*-voice",                  "not AddVoice",
-    "&",                        "AddSynth & PadSynth only",
-    "#",                        "SubSynth & PadSynth only",
-    "","The common list is deprecated and will eventually be removed.",
-    "@end","@end"
-};
-
 std::string addsynthlist [] = {
     "<ON/OFF>",                 "enables/disables the part",
     "Volume <n>",               "volume",
@@ -998,7 +954,7 @@ std::string scale_errors [] = {
     "Invalid octave size",
     "Invalid keymap size",
     "Invalid note number",
-    "Value out of range",
+    "Value out of range", // translated as -12
     "@end"
 
 };
