@@ -19,6 +19,7 @@
 */
 
 #include <string>
+#include <memory>
 
 #include "Misc/XMLwrapper.h"
 #include "Misc/SynthEngine.h"
@@ -26,6 +27,7 @@
 #include "Misc/FileMgrFuncs.h"
 #include "Interface/TextLists.h"
 #include "Effects/EffectMgr.h"
+#include "Params/UnifiedPresets.h"
 #include "Params/ADnoteParameters.h"
 #include "Params/SUBnoteParameters.h"
 #include "Params/PADnoteParameters.h"
@@ -35,27 +37,25 @@
 
 
 using std::string;
+using std::to_string;
 
-/*
-   type flags (set)
-        List  - all entries of section type
-        Group - preset extension and name
-        Copy  - from section to file
-        Paste - from file to section
-
-   no name given - from/to clipboard))
+/**
+ * type flags (set)
+ *      List  - all entries of section type
+ *      Group - preset extension and name
+ *      Copy  - from section to file
+ *      Paste - from file to section
+ *
+ * no name given - from/to clipboard))
  */
-
-string UnifiedPresets::section(SynthEngine *_synth, CommandBlock *getData)
+string UnifiedPresets::handleStoreLoad()
 {
-    synth = _synth;
-    //synth->CBtest(getData, true);
-    int type = getData->data.type;
-    int value = getData->data.value;
+    int type = cmd.data.type;
+    int value = cmd.data.value;
     human = value; // used for listing. 'value may change before it is read
     if (type == TOPLEVEL::type::List && human > 0)
     {
-        string group = findPresetType(getData);
+        string group{findPresetType()};
         if (human == 2)
         {
             /* here we abuse the list routines in order to find out
@@ -71,17 +71,17 @@ string UnifiedPresets::section(SynthEngine *_synth, CommandBlock *getData)
          * sending a message here was doubling the number of messages
          * but only one was actually being read!
          */
-        value = UNUSED;//synth->textMsgBuffer.push(group);
-        return findPresetType(getData); // human friendly extension
+        value = UNUSED;
+        return findPresetType(); // human friendly extension
     }
 
-    string name = findPresetType(getData);
+    string name{findPresetType()};
     if (name.empty())
     {
         name = "No section presets in this context";
         return name;
     }
-    string dirname = synth->getRuntime().presetsDirlist[synth->getRuntime().presetsRootID];
+    string dirname{synth.getRuntime().presetsDirlist[synth.getRuntime().presetsRootID]};
     if (dirname.empty())
     {
         name = "Directory empty";
@@ -96,37 +96,37 @@ string UnifiedPresets::section(SynthEngine *_synth, CommandBlock *getData)
     {
         if (type & TOPLEVEL::type::Copy)
         {
-            saveUnif(getData);
+            save();
             name = "";
         }
         else if (type & TOPLEVEL::type::Paste)
         {
             if (human == 0)
-                load(getData);
+                load();
             else
-                remove(getData);
+                remove();
         }
     }
     return name;
 }
 
-string UnifiedPresets::listpos(int count)
+string UnifiedPresets::listpos(int count)  const
 {
- // If human = 2 we want to get the extension not the freindly name
+ // If human = 2 we want to get the extension not the friendly name
     int test = 0;
     if (human == 1)
         test = 1;
     return presetgroups[count * 2 + test];
 }
 
-string UnifiedPresets::findPresetType(CommandBlock *getData)
+string UnifiedPresets::findPresetType()
 {
-    int npart = getData->data.part;
-    int kitItem = getData->data.kit;
-    int engineType = getData->data.engine;
-    int insert = getData->data.insert;
-    int parameter = getData->data.parameter;
-    int offset = getData->data.offset;
+    int npart = cmd.data.part;
+    int kitItem = cmd.data.kit;
+    int engineType = cmd.data.engine;
+    int insert = cmd.data.insert;
+    int parameter = cmd.data.parameter;
+    int offset = cmd.data.offset;
     string name = "";
 
     if (npart != TOPLEVEL::section::systemEffects && npart != TOPLEVEL::section::insertEffects && npart > TOPLEVEL::section::part64)
@@ -242,14 +242,14 @@ void UnifiedPresets::list(string dirname, string& name)
 }
 
 
-string UnifiedPresets::findXML(XMLwrapper *xml, CommandBlock *getData, bool isLoad)
+string UnifiedPresets::accessXML(XMLwrapper& xml, bool isLoad)
 {
-    int npart = getData->data.part;
-    int kitItem = getData->data.kit;
-    int engineType = getData->data.engine;
-    int insert = getData->data.insert;
+    int npart = cmd.data.part;
+    int kitItem = cmd.data.kit;
+    int engineType = cmd.data.engine;
+    int insert = cmd.data.insert;
 
-    string name = "";
+    string name;
 
     if (kitItem == EFFECT::type::dynFilter && insert == TOPLEVEL::insert::filterGroup)
     {
@@ -261,30 +261,31 @@ string UnifiedPresets::findXML(XMLwrapper *xml, CommandBlock *getData, bool isLo
             EffectMgr *sectionType;
             if (npart == TOPLEVEL::section::systemEffects)
             {
-                sectionType = synth->sysefx[engineType];
+                sectionType = synth.sysefx[engineType];
             }
             else if (npart == TOPLEVEL::section::insertEffects)
             {
-                sectionType = synth->insefx[engineType];
+                sectionType = synth.insefx[engineType];
             }
             else
             {
-                sectionType = synth->part[npart]->partefx[engineType];
+                sectionType = synth.part[npart]->partefx[engineType];
             }
             name = "Peffect";
 
             if (isLoad)
             {
                 sectionType->defaults();
-                xml->enterbranch(name);
+                xml.enterbranch(name);
                 sectionType->getfromXML(xml);
-                xml->exitbranch();
+                xml.exitbranch();
+                synth.pushEffectUpdate(npart);
             }
             else
             {
-                xml->beginbranch(name);
+                xml.beginbranch(name);
                 sectionType->add2XML(xml);
-                xml->endbranch();
+                xml.endbranch();
             }
         }
     }
@@ -296,31 +297,31 @@ string UnifiedPresets::findXML(XMLwrapper *xml, CommandBlock *getData, bool isLo
         {
             case TOPLEVEL::insert::resonanceGroup:
             {
-                name = resonanceXML(xml, getData, isLoad);
+                name = resonanceXML(xml, isLoad);
             }
             break;
 
             case TOPLEVEL::insert::oscillatorGroup:
             {
-                name = oscilXML(xml, getData, isLoad);
+                name = oscilXML(xml, isLoad);
             }
             break;
 
             case TOPLEVEL::insert::filterGroup:
             {
-                name = filterXML(xml, getData, isLoad);
+                name = filterXML(xml, isLoad);
             }
             break;
 
             case TOPLEVEL::insert::LFOgroup:
             {
-                name = lfoXML(xml, getData, isLoad);
+                name = lfoXML(xml, isLoad);
             }
             break;
 
             case TOPLEVEL::insert::envelopeGroup:
             {
-                name = envelopeXML(xml, getData, isLoad);
+                name = envelopeXML(xml, isLoad);
             }
             break;
         }
@@ -331,81 +332,81 @@ string UnifiedPresets::findXML(XMLwrapper *xml, CommandBlock *getData, bool isLo
     if (engineType == PART::engine::addSynth)
     {
         name = "Padsyth";
-        ADnoteParameters *sectionType = synth->part[npart]->kit[kitItem].adpars;
+        ADnoteParameters *sectionType = synth.part[npart]->kit[kitItem].adpars;
 
         if (isLoad)
         {
             sectionType->defaults();
-            xml->enterbranch(name);
+            xml.enterbranch(name);
             sectionType->getfromXML(xml);
-            xml->exitbranch();
+            xml.exitbranch();
         }
         else
         {
-            xml->beginbranch(name);
+            xml.beginbranch(name);
             sectionType->add2XML(xml);
-            xml->endbranch();
+            xml.endbranch();
         }
     }
 
     else if (engineType >= PART::engine::addVoice1)
     {
         name = "Padsythn";
-        ADnoteParameters *sectionType = synth->part[npart]->kit[kitItem].adpars;
+        ADnoteParameters *sectionType = synth.part[npart]->kit[kitItem].adpars;
         size_t voice = engineType - PART::engine::addVoice1;
 
         if (isLoad)
         {
             sectionType->voiceDefaults(voice);
-            xml->enterbranch(name);
+            xml.enterbranch(name);
             sectionType->getfromXMLsection(xml, voice);
-            xml->exitbranch();
+            xml.exitbranch();
         }
         else
         {
-            xml->beginbranch(name);
+            xml.beginbranch(name);
             sectionType->add2XMLsection(xml, voice);
-            xml->endbranch();
+            xml.endbranch();
         }
     }
 
     else if (engineType == PART::engine::subSynth)
     {
         name = "Psubsyth";
-        SUBnoteParameters *sectionType = synth->part[npart]->kit[kitItem].subpars;
+        SUBnoteParameters *sectionType = synth.part[npart]->kit[kitItem].subpars;
 
         if (isLoad)
         {
             sectionType->defaults();
-            xml->enterbranch(name);
+            xml.enterbranch(name);
             sectionType->getfromXML(xml);
-            xml->endbranch();
+            xml.endbranch();
         }
         else
         {
-            xml->beginbranch(name);
+            xml.beginbranch(name);
             sectionType->add2XML(xml);
-            xml->endbranch();
+            xml.endbranch();
         }
     }
 
     else if (engineType == PART::engine::padSynth)
     {
         name = "Ppadsyth";
-        PADnoteParameters * sectionType = synth->part[npart]->kit[kitItem].padpars;
+        PADnoteParameters * sectionType = synth.part[npart]->kit[kitItem].padpars;
 
         if (isLoad)
         {
             sectionType->defaults();
-            xml->enterbranch(name);
+            xml.enterbranch(name);
             sectionType->getfromXML(xml);
-            xml->exitbranch();
+            xml.exitbranch();
         }
         else
         {
-            xml->beginbranch(name);
+            xml.beginbranch(name);
             sectionType->add2XML(xml);
-            xml->endbranch();
+            xml.endbranch();
         }
     }
 
@@ -413,48 +414,48 @@ string UnifiedPresets::findXML(XMLwrapper *xml, CommandBlock *getData, bool isLo
 }
 
 
-string UnifiedPresets::resonanceXML(XMLwrapper *xml,CommandBlock *getData, bool isLoad)
+string UnifiedPresets::resonanceXML(XMLwrapper& xml, bool isLoad)
 {
-    int npart = getData->data.part;
-    int kitItem = getData->data.kit;
-    int engineType = getData->data.engine;
-    string name = "Presonance";
-    Resonance *sectionType;
+    int npart = cmd.data.part;
+    int kitItem = cmd.data.kit;
+    int engineType = cmd.data.engine;
+    string name{"Presonance"};
+    Resonance* sectionType;
 
     if (engineType == PART::engine::addSynth)
     {
-        sectionType = synth->part[npart]->kit[kitItem].adpars->GlobalPar.Reson;
+        sectionType = synth.part[npart]->kit[kitItem].adpars->GlobalPar.Reson;
     }
     else if (engineType == PART::engine::padSynth)
     {
-        sectionType = synth->part[npart]->kit[kitItem].padpars->resonance.get();
+        sectionType = synth.part[npart]->kit[kitItem].padpars->resonance.get();
     }
     else
         return "";
 
     if (isLoad)
     {
-        xml->enterbranch(name);
+        xml.enterbranch(name);
         sectionType->getfromXML(xml);
-        xml->exitbranch();
+        xml.exitbranch();
     }
     else
     {
-        xml->beginbranch(name);
+        xml.beginbranch(name);
         sectionType->add2XML(xml);
-        xml->endbranch();
+        xml.endbranch();
     }
 
     return name;
 }
 
 
-string UnifiedPresets::oscilXML(XMLwrapper *xml,CommandBlock *getData, bool isLoad)
+string UnifiedPresets::oscilXML(XMLwrapper& xml, bool isLoad)
 {
-    int npart = getData->data.part;
-    int kitItem = getData->data.kit;
-    int engineType = getData->data.engine;
-    string name = "Poscilgen";
+    int npart = cmd.data.part;
+    int kitItem = cmd.data.kit;
+    int engineType = cmd.data.engine;
+    string name{"Poscilgen"};
 
     OscilParameters *sectionType;
 
@@ -463,43 +464,43 @@ string UnifiedPresets::oscilXML(XMLwrapper *xml,CommandBlock *getData, bool isLo
         if (engineType >= PART::engine::addMod1)
         {
             engineType -= NUM_VOICES;
-            sectionType = synth->part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].POscilFM;
+            sectionType = synth.part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].POscilFM;
         }
         else
         {
-            sectionType = synth->part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].POscil;
+            sectionType = synth.part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].POscil;
         }
     }
     else if (engineType == PART::engine::padSynth)
     {
-        sectionType = synth->part[npart]->kit[kitItem].padpars->POscil.get();
+        sectionType = synth.part[npart]->kit[kitItem].padpars->POscil.get();
     }
     else
         return "";
 
     if (isLoad)
     {
-        xml->enterbranch(name);
+        xml.enterbranch(name);
         sectionType->getfromXML(xml);
-        xml->exitbranch();
+        xml.exitbranch();
     }
     else
     {
-        xml->beginbranch(name);
+        xml.beginbranch(name);
         sectionType->add2XML(xml);
-        xml->endbranch();
+        xml.endbranch();
     }
 
     return name;
 }
 
 
-string UnifiedPresets::filterXML(XMLwrapper *xml, CommandBlock *getData, bool isLoad)
+string UnifiedPresets::filterXML(XMLwrapper& xml, bool isLoad)
 {
-    int npart = getData->data.part;
-    int kitItem = getData->data.kit;
-    int engineType = getData->data.engine;
-    int offset = getData->data.offset;
+    int npart = cmd.data.part;
+    int kitItem = cmd.data.kit;
+    int engineType = cmd.data.engine;
+    int offset = cmd.data.offset;
     string name;
     if (offset == UNUSED)
     {
@@ -515,33 +516,33 @@ string UnifiedPresets::filterXML(XMLwrapper *xml, CommandBlock *getData, bool is
     // top level
     if (npart == TOPLEVEL::section::systemEffects)
     {
-        sectionType = synth->sysefx[0]->filterpars;
+        sectionType = synth.sysefx[0]->filterpars;
     }
     else if (npart == TOPLEVEL::section::insertEffects)
     {
-        sectionType = synth->insefx[0]->filterpars;
+        sectionType = synth.insefx[0]->filterpars;
     }
 
     // part level
     else if (kitItem == EFFECT::type::dynFilter)
     {
-        sectionType = synth->part[npart]->partefx[0]->filterpars;
+        sectionType = synth.part[npart]->partefx[0]->filterpars;
     }
     else if (engineType == PART::engine::addSynth)
     {
-        sectionType = synth->part[npart]->kit[kitItem].adpars->GlobalPar.GlobalFilter;
+        sectionType = synth.part[npart]->kit[kitItem].adpars->GlobalPar.GlobalFilter;
     }
     else if (engineType >= PART::engine::addVoice1)
     {
-        sectionType = synth->part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].VoiceFilter;
+        sectionType = synth.part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].VoiceFilter;
     }
     else if (engineType == PART::engine::subSynth)
     {
-        sectionType = synth->part[npart]->kit[kitItem].subpars->GlobalFilter;
+        sectionType = synth.part[npart]->kit[kitItem].subpars->GlobalFilter;
     }
     else if (engineType == PART::engine::padSynth)
     {
-        sectionType = synth->part[npart]->kit[kitItem].padpars->GlobalFilter.get();
+        sectionType = synth.part[npart]->kit[kitItem].padpars->GlobalFilter.get();
     }
     else
     {
@@ -552,30 +553,30 @@ string UnifiedPresets::filterXML(XMLwrapper *xml, CommandBlock *getData, bool is
     {
         if (offset == UNUSED)
         {
-            xml->enterbranch(name);
+            xml.enterbranch(name);
             sectionType->getfromXML(xml);
-            xml->exitbranch();
+            xml.exitbranch();
         }
         else
         {
-            xml->enterbranch(name);
+            xml.enterbranch(name);
             sectionType->getfromXMLsection(xml, offset);
-            xml->exitbranch();
+            xml.exitbranch();
         }
     }
     else
     {
         if (offset == UNUSED)
         {
-            xml->beginbranch(name);
+            xml.beginbranch(name);
             sectionType->add2XML(xml);
-            xml->endbranch();
+            xml.endbranch();
         }
         else
         {
-            xml->beginbranch(name);
+            xml.beginbranch(name);
             sectionType->add2XMLsection(xml, offset);
-            xml->endbranch();
+            xml.endbranch();
         }
     }
 
@@ -583,15 +584,15 @@ string UnifiedPresets::filterXML(XMLwrapper *xml, CommandBlock *getData, bool is
 }
 
 
-string UnifiedPresets::lfoXML(XMLwrapper *xml,CommandBlock *getData, bool isLoad)
+string UnifiedPresets::lfoXML(XMLwrapper& xml, bool isLoad)
 {
-    int npart = getData->data.part;
-    int kitItem = getData->data.kit;
-    int engineType = getData->data.engine;
-    int parameter = getData->data.parameter;
+    int npart = cmd.data.part;
+    int kitItem = cmd.data.kit;
+    int engineType = cmd.data.engine;
+    int parameter = cmd.data.parameter;
 
     string name;
-    LFOParams *sectionType;
+    LFOParams *sectionType = NULL;
 
     if (engineType == PART::engine::addSynth)
     {
@@ -599,15 +600,15 @@ string UnifiedPresets::lfoXML(XMLwrapper *xml,CommandBlock *getData, bool isLoad
         {
             case 0:
                 name = "Plfoamplitude";
-                sectionType = synth->part[npart]->kit[kitItem].adpars->GlobalPar.AmpLfo;
+                sectionType = synth.part[npart]->kit[kitItem].adpars->GlobalPar.AmpLfo;
             break;
             case 1:
                 name = "Plfofrequency";
-                sectionType = synth->part[npart]->kit[kitItem].adpars->GlobalPar.FreqLfo;
+                sectionType = synth.part[npart]->kit[kitItem].adpars->GlobalPar.FreqLfo;
             break;
             case 2:
                 name = "Plfofilter";
-                sectionType = synth->part[npart]->kit[kitItem].adpars->GlobalPar.FilterLfo;
+                sectionType = synth.part[npart]->kit[kitItem].adpars->GlobalPar.FilterLfo;
             break;
         }
     }
@@ -617,15 +618,15 @@ string UnifiedPresets::lfoXML(XMLwrapper *xml,CommandBlock *getData, bool isLoad
         {
             case 0:
                 name = "Plfoamplitude";
-                sectionType = synth->part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].AmpLfo;
+                sectionType = synth.part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].AmpLfo;
             break;
             case 1:
                 name = "Plfofrequency";
-                sectionType = synth->part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].FreqLfo;
+                sectionType = synth.part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].FreqLfo;
             break;
             case 2:
                 name = "Plfofilter";
-                sectionType = synth->part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].FilterLfo;
+                sectionType = synth.part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].FilterLfo;
             break;
         }
     }
@@ -635,15 +636,15 @@ string UnifiedPresets::lfoXML(XMLwrapper *xml,CommandBlock *getData, bool isLoad
         {
             case 0:
                 name = "Plfoamplitude";
-                sectionType = synth->part[npart]->kit[kitItem].padpars->AmpLfo.get();
+                sectionType = synth.part[npart]->kit[kitItem].padpars->AmpLfo.get();
             break;
             case 1:
                 name = "Plfofrequency";
-                sectionType = synth->part[npart]->kit[kitItem].padpars->FreqLfo.get();
+                sectionType = synth.part[npart]->kit[kitItem].padpars->FreqLfo.get();
             break;
             case 2:
                 name = "Plfofilter";
-                sectionType = synth->part[npart]->kit[kitItem].padpars->FilterLfo.get();
+                sectionType = synth.part[npart]->kit[kitItem].padpars->FilterLfo.get();
             break;
         }
     }
@@ -653,45 +654,45 @@ string UnifiedPresets::lfoXML(XMLwrapper *xml,CommandBlock *getData, bool isLoad
 
     if (isLoad)
     {
-        xml->enterbranch(name);
+        xml.enterbranch(name);
         sectionType->getfromXML(xml);
-        xml->exitbranch();
+        xml.exitbranch();
     }
     else
     {
-        xml->beginbranch(name);
+        xml.beginbranch(name);
         sectionType->add2XML(xml);
-        xml->endbranch();
+        xml.endbranch();
     }
 
     return name;
 }
 
 
-string UnifiedPresets::envelopeXML(XMLwrapper *xml,CommandBlock *getData, bool isLoad)
+string UnifiedPresets::envelopeXML(XMLwrapper& xml, bool isLoad)
 {
-    int npart = getData->data.part;
-    int kitItem = getData->data.kit;
-    int engineType = getData->data.engine;
-    int parameter = getData->data.parameter;
+    int npart = cmd.data.part;
+    int kitItem = cmd.data.kit;
+    int engineType = cmd.data.engine;
+    int parameter = cmd.data.parameter;
 
     string name;
-    EnvelopeParams *sectionType;
+    EnvelopeParams* sectionType{nullptr};
     if (engineType == PART::engine::addSynth)
     {
         switch (parameter)
         {
             case 0:
                 name = "Penvamplitude";
-                sectionType = synth->part[npart]->kit[kitItem].adpars->GlobalPar.AmpEnvelope;
+                sectionType = synth.part[npart]->kit[kitItem].adpars->GlobalPar.AmpEnvelope;
             break;
             case 1:
                 name = "Penvfrequency";
-                sectionType = synth->part[npart]->kit[kitItem].adpars->GlobalPar.FreqEnvelope;
+                sectionType = synth.part[npart]->kit[kitItem].adpars->GlobalPar.FreqEnvelope;
             break;
             case 2:
                 name = "Penvfilter";
-                sectionType = synth->part[npart]->kit[kitItem].adpars->GlobalPar.FilterEnvelope;
+                sectionType = synth.part[npart]->kit[kitItem].adpars->GlobalPar.FilterEnvelope;
             break;
         }
     }
@@ -702,15 +703,15 @@ string UnifiedPresets::envelopeXML(XMLwrapper *xml,CommandBlock *getData, bool i
         {
             case 0:
                 name = "Penvamplitude";
-                sectionType = synth->part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].AmpEnvelope;
+                sectionType = synth.part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].AmpEnvelope;
             break;
             case 1:
                 name = "Penvfrequency";
-                sectionType = synth->part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].FreqEnvelope;
+                sectionType = synth.part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].FreqEnvelope;
             break;
             case 2:
                 name = "Penvfilter";
-                sectionType = synth->part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].FilterEnvelope;
+                sectionType = synth.part[npart]->kit[kitItem].adpars->VoicePar[engineType - PART::engine::addVoice1].FilterEnvelope;
             break;
         }
     }
@@ -721,19 +722,19 @@ string UnifiedPresets::envelopeXML(XMLwrapper *xml,CommandBlock *getData, bool i
         {
             case 0:
                 name = "Penvamplitude";
-                sectionType = synth->part[npart]->kit[kitItem].subpars->AmpEnvelope;
+                sectionType = synth.part[npart]->kit[kitItem].subpars->AmpEnvelope;
             break;
             case 1:
                 name = "Penvfrequency";
-                sectionType = synth->part[npart]->kit[kitItem].subpars->FreqEnvelope;
+                sectionType = synth.part[npart]->kit[kitItem].subpars->FreqEnvelope;
             break;
             case 2:
                 name = "Penvfilter";
-                sectionType = synth->part[npart]->kit[kitItem].subpars->GlobalFilterEnvelope;
+                sectionType = synth.part[npart]->kit[kitItem].subpars->GlobalFilterEnvelope;
             break;
             case 3:
                 name = "Penvbandwidth";
-                sectionType = synth->part[npart]->kit[kitItem].subpars->BandWidthEnvelope;
+                sectionType = synth.part[npart]->kit[kitItem].subpars->BandWidthEnvelope;
             break;
         }
     }
@@ -744,15 +745,15 @@ string UnifiedPresets::envelopeXML(XMLwrapper *xml,CommandBlock *getData, bool i
         {
             case 0:
                 name = "Penvamplitude";
-                sectionType = synth->part[npart]->kit[kitItem].padpars->AmpEnvelope.get();
+                sectionType = synth.part[npart]->kit[kitItem].padpars->AmpEnvelope.get();
             break;
             case 1:
                 name = "Penvfrequency";
-                sectionType = synth->part[npart]->kit[kitItem].padpars->FreqEnvelope.get();
+                sectionType = synth.part[npart]->kit[kitItem].padpars->FreqEnvelope.get();
             break;
             case 2:
                 name = "Penvfilter";
-                sectionType = synth->part[npart]->kit[kitItem].padpars->FilterEnvelope.get();
+                sectionType = synth.part[npart]->kit[kitItem].padpars->FilterEnvelope.get();
             break;
         }
     }
@@ -762,57 +763,55 @@ string UnifiedPresets::envelopeXML(XMLwrapper *xml,CommandBlock *getData, bool i
 
     if (isLoad)
     {
-        xml->enterbranch(name);
+        xml.enterbranch(name);
         sectionType->getfromXML(xml);
-        xml->exitbranch();
+        xml.exitbranch();
     }
     else
     {
-        xml->beginbranch(name);
+        xml.beginbranch(name);
         sectionType->add2XML(xml);
-        xml->endbranch();
+        xml.endbranch();
     }
 
     return name;
 }
 
 
-bool UnifiedPresets::saveUnif(CommandBlock *getData)
+void UnifiedPresets::save()
 {
-    synth->getRuntime().xmlType = TOPLEVEL::XML::Presets;
-    XMLwrapper *xml = new XMLwrapper(synth, false);
-    string type = findXML(xml, getData, false);
+    synth.getRuntime().xmlType = TOPLEVEL::XML::Presets;
+    auto xml{std::make_unique<XMLwrapper>(synth, false)};
+    string type{accessXML(*xml, false)};
     if (type.empty())
-        synth->getRuntime().Log("Unrecognised preset type");
+        synth.getRuntime().Log("Unrecognised preset type");
     else
     {
         string dirname;
-        string name = synth->textMsgBuffer.fetch(getData->data.miscmsg);
+        string name = synth.textMsgBuffer.fetch(cmd.data.miscmsg);
         if (name.empty())
         {
             dirname = file::localDir() + "/clipboard";
             if (file::createDir(dirname))
-                synth->getRuntime().Log("Failed to open clipboard directory");
+                synth.getRuntime().Log("Failed to open clipboard directory");
             else
                 xml->saveXMLfile(dirname + "/section." + type + EXTEN::presets);
         }
         else
         {
-            dirname = synth->getRuntime().presetsDirlist[synth->getRuntime().presetsRootID];
+            dirname = synth.getRuntime().presetsDirlist[synth.getRuntime().presetsRootID];
             xml->saveXMLfile(dirname + "/" + name + "." + type + EXTEN::presets);
         }
     }
-    delete xml;
-    return false;
 }
 
 
-bool UnifiedPresets::load(CommandBlock *getData)
+void UnifiedPresets::load()
 {
-    synth->getRuntime().xmlType = TOPLEVEL::XML::Presets;
-    string type = findPresetType(getData);
-    XMLwrapper *xml = new XMLwrapper(synth, false);
-    string name = synth->textMsgBuffer.fetch(getData->data.miscmsg);
+    synth.getRuntime().xmlType = TOPLEVEL::XML::Presets;
+    string type{findPresetType()};
+    auto xml{std::make_unique<XMLwrapper>(synth, false)};
+    string name = synth.textMsgBuffer.fetch(cmd.data.miscmsg);
     string dirname;
     string prefix;
 
@@ -821,7 +820,7 @@ bool UnifiedPresets::load(CommandBlock *getData)
         dirname = file::localDir() + "/clipboard";
         if (file::createDir(dirname))
         {
-            synth->getRuntime().Log("Failed to open clipboard directory");
+            synth.getRuntime().Log("Failed to open clipboard directory");
         }
         else
         {
@@ -830,31 +829,25 @@ bool UnifiedPresets::load(CommandBlock *getData)
     }
     else
     {
-        dirname = synth->getRuntime().presetsDirlist[synth->getRuntime().presetsRootID];
+        dirname = synth.getRuntime().presetsDirlist[synth.getRuntime().presetsRootID];
         prefix = dirname + "/" + name + ".";
     }
     string filename = prefix + type + EXTEN::presets;
 
     if (file::isRegularFile(prefix + type + EXTEN::presets) == 0)
-    {
-        synth->getRuntime().Log("Can't match " + filename + " here.");
-        return false;
-    }
+        synth.getRuntime().Log("Can't match " + filename + " here.");
 
     xml->loadXMLfile(filename);
-    findXML(xml, getData, true);
-    delete xml;
-    return false;
+    accessXML(*xml, true);
 }
 
-bool UnifiedPresets::remove(CommandBlock *getData)
+
+void UnifiedPresets::remove()
 {
     human = 0; // we need the extension this time.
-    string type = findPresetType(getData);
-    string name = synth->textMsgBuffer.fetch(getData->data.miscmsg);
-    string dirname = synth->getRuntime().presetsDirlist[synth->getRuntime().presetsRootID];
+    string type = findPresetType();
+    string name = synth.textMsgBuffer.fetch(cmd.data.miscmsg);
+    string dirname = synth.getRuntime().presetsDirlist[synth.getRuntime().presetsRootID];
     string filename = dirname + "/" + name + "." + type + EXTEN::presets;
-    //std::cout << "file >" << filename << std::endl;
     file::deleteFile(filename);
-    return false;
 }
