@@ -27,8 +27,9 @@
 #include <string>
 #include <iostream>
 
-typedef unsigned char uchar;
-typedef unsigned int  uint;
+using uint = unsigned int;
+using uchar = unsigned char;
+using ushort = unsigned short;
 
 /*
  * For test purposes where you want guaranteed identical results, enable the
@@ -148,7 +149,7 @@ namespace _SYS_
 
 namespace TOPLEVEL // usage TOPLEVEL::section::vector
 {
-    enum section : unsigned char {
+    enum section : uchar {
         part1 = 0,   // nothing must come
         part64 = 63, // between these two
 
@@ -178,11 +179,11 @@ namespace TOPLEVEL // usage TOPLEVEL::section::vector
         enum {
             // bits 0, 1 as values
             Adjust = 0, // return value adjusted within limits
-            Minimum, // return this value
-            Maximum, // return this value
-            Default, // return this value
+            Minimum, // 1 return this value
+            Maximum, // 2 return this value
+            Default, // 3 return this value
             // remaining used bit-wise
-            Limits, // read limits shown above
+            Limits, // 4 read limits shown above
             Error = 8,
             LearnRequest = 16,
             Learnable = 32,
@@ -213,12 +214,13 @@ namespace TOPLEVEL // usage TOPLEVEL::section::vector
         };
     }
 
-    enum control : unsigned char {
+    enum control : uchar {
         // insert any new entries here
         /*
          * the following values must never appear in any other sections
          * they are all callable from any section
          */
+        dataExchange = 250,//FA
         copyPaste =  251, // FB
         partBusy, // internally generated - read only
         unrecognised,
@@ -226,7 +228,7 @@ namespace TOPLEVEL // usage TOPLEVEL::section::vector
         forceExit
     };
 
-    enum msgResponse : unsigned char {
+    enum msgResponse : uchar {
         refreshBankDefaults,
         cancelBankDefaults,
         cancelMidiLearn
@@ -236,7 +238,7 @@ namespace TOPLEVEL // usage TOPLEVEL::section::vector
 
     // inserts are here as they are split between many
     // sections but must remain distinct.
-    enum insert : unsigned char {
+    enum insert : uchar {
         LFOgroup = 0,
         filterGroup,
         envelopeGroup,
@@ -254,14 +256,14 @@ namespace TOPLEVEL // usage TOPLEVEL::section::vector
         kitGroup
     };
 
-    enum insertType : unsigned char {
+    enum insertType : uchar {
         amplitude = 0,
         frequency,
         filter,
         bandwidth
     };
 
-    enum filter :unsigned char {
+    enum filter : uchar {
         Low1 = 0,
         High1,
         Low2,
@@ -270,10 +272,10 @@ namespace TOPLEVEL // usage TOPLEVEL::section::vector
         Notch2,
         Peak2,
         LowShelf2,
-        HighShelf2
+        HighShelf2             // NOTE: also used to limit valid filter type codes. See AnalogFilter
     };
 
-    enum XML : unsigned char { // file and history types
+    enum XML : uchar {  // file and history types
         Instrument = 0, // individual externally sourced Instruments
         Patch, //      full instrument Patch Sets
         Scale, //      complete Microtonal settings
@@ -291,6 +293,7 @@ namespace TOPLEVEL // usage TOPLEVEL::section::vector
         // only file types from here onwards
         Config,
         MasterConfig,
+        MasterUpdate,
         Bank,
         History,
         PresetDirs,
@@ -300,37 +303,40 @@ namespace TOPLEVEL // usage TOPLEVEL::section::vector
 
 namespace CONFIG // usage CONFIG::control::oscillatorSize
 {
-    enum control : unsigned char {
-        oscillatorSize = 0,
+    enum control : uchar {
+        enableGUI = 0,
+        showSplash,
+        enableCLI,
+        exposeStatus, // CLI only
+        enableSinglePath,
+        enableAutoInstance,
+        handlePadSynthBuild,   // how to build PADSynth wavetable;
+        // 0=legacy/muted, 1=background thread, 2=autoApply
+        banksChecked,
+        XMLcompressionLevel,   // this must be the last entry for base config.
+
+        defaultStateStart = 16, // must be first entry for state/session data
         bufferSize,
-        padSynthInterpolation,
-        virtualKeyboardLayout,
-        XMLcompressionLevel,
+        oscillatorSize,
         reportsDestination,
         logTextSize,
+        padSynthInterpolation,
+        virtualKeyboardLayout,
         savedInstrumentFormat,
-        defaultStateStart = 16,
         hideNonFatalErrors,
-        showSplash,
         logInstrumentLoadTimes,
         logXMLheaders,
         saveAllXMLdata,
-        enableGUI,
-        enableCLI,
-        enableAutoInstance,
-        enableSinglePath,
-        historyLock,
-        exposeStatus, // CLI only
-        enableHighlight, // in banks
-        handlePadSynthBuild,   // how to build PADSynth wavetable; 0=legacy/muted, 1=background thread, 2=autoApply
+        enableHighlight,
+
 
         // start of engine controls
-        jackMidiSource = 32,
+        jackMidiSource,
         jackPreferredMidi,
         jackServer,
         jackPreferredAudio,
         jackAutoConnectAudio,
-        alsaMidiSource = 48,
+        alsaMidiSource,
         alsaPreferredMidi,
         alsaMidiType,
         alsaAudioDevice,
@@ -340,24 +346,29 @@ namespace CONFIG // usage CONFIG::control::oscillatorSize
         readMIDI,
         // end of engine controls
 
-        addPresetRootDir = 60,
+        addPresetRootDir,
         removePresetRootDir,
         currentPresetRoot,
-        bankRootCC = 65,
-        bankCC = 67,
+        bankRootCC,
+        bankCC,
         enableProgramChange,
-        extendedProgramChangeCC = 71,
+        extendedProgramChangeCC,
         ignoreResetAllCCs,
         logIncomingCCs,
         showLearnEditor,
         enableNRPNs,
-        saveCurrentConfig = 80
+        saveCurrentConfig,
+        changeRoot, // dummy command - always save current root
+        changeBank, // dummy command - always save current bank
+
+        historyLock // these are stored in local/share/Yoshimi/recent
+                    // as the first entry of each section
     };
 }
 
 namespace BANK // usage BANK::control::
 {
-    enum control : unsigned char {
+    enum control : uchar {
         // instrument selection done in 'part'
         // actual control should probably be here
         readInstrumentName = 0, // in bank, by ID
@@ -390,7 +401,7 @@ namespace BANK // usage BANK::control::
 
 namespace VECTOR // usage VECTOR::control::name
 {
-    enum control : unsigned char {
+    enum control : uchar {
         undefined = 0,
         name = 8,
         Xcontroller = 16,
@@ -413,7 +424,7 @@ namespace VECTOR // usage VECTOR::control::name
 
 namespace MIDILEARN // usage MIDILEARN::control::block
 {
-    enum control : unsigned char {
+    enum control : uchar {
         block = 0,
         limit,
         mute,
@@ -442,7 +453,7 @@ namespace MIDILEARN // usage MIDILEARN::control::block
 
 namespace MIDI // usage MIDI::control::noteOn
 {
-    enum control : unsigned char {
+    enum control : uchar {
         noteOn = 0,
         noteOff,
         controller,
@@ -451,7 +462,7 @@ namespace MIDI // usage MIDI::control::noteOn
     };
 // the following are actual MIDI numbers
 // not to be confused with part controls!
-    enum CC : unsigned short int {
+    enum CC : ushort {
         bankSelectMSB = 0,
         modulation,
         breath,
@@ -497,7 +508,7 @@ namespace MIDI // usage MIDI::control::noteOn
         null
     };
 
-    enum SoloType : unsigned char {
+    enum SoloType : uchar {
         Disabled = 0,
         Row,
         Column,
@@ -509,7 +520,7 @@ namespace MIDI // usage MIDI::control::noteOn
 
 namespace SCALES // usage SCALES::control::refFrequency
 {
-    enum control : unsigned char {
+    enum control : uchar {
         enableMicrotonal = 0,
         refFrequency,
         refNote,
@@ -550,7 +561,7 @@ namespace SCALES // usage SCALES::control::refFrequency
 
 namespace MAIN // usage MAIN::control::volume
 {
-    enum control : unsigned char {
+    enum control : uchar {
         mono = 0,
         volume,
         partNumber = 14,
@@ -596,7 +607,7 @@ namespace MAIN // usage MAIN::control::volume
         readMainLRrms
     };
 
-    enum panningType : unsigned char {
+    enum panningType : uchar {
         cut = 0,
         normal,
         boost
@@ -606,7 +617,7 @@ namespace MAIN // usage MAIN::control::volume
 
 namespace PART // usage PART::control::volume
 {
-    enum control : unsigned char {
+    enum control : uchar {
         enable = 0,
         enableAdd,
         enableSub,
@@ -693,14 +704,14 @@ namespace PART // usage PART::control::volume
         defaultInstrumentCopyright, // this needs to be split into two for load/save
     };
 
-    enum kitType : unsigned char {
+    enum kitType : uchar {
         Off = 0,
         Multi,
         Single,
         CrossFade
     };
 
-    enum engine : unsigned char {
+    enum engine : uchar {
         addSynth = 0,
         subSynth,
         padSynth,
@@ -739,7 +750,7 @@ namespace PART // usage PART::control::volume
 
 namespace ADDSYNTH // usage ADDSYNTH::control::volume
 {
-    enum control : unsigned char {
+    enum control : uchar {
         volume = 0,
         velocitySense,
         panning,
@@ -766,7 +777,7 @@ namespace ADDSYNTH // usage ADDSYNTH::control::volume
 
 namespace ADDVOICE // usage ADDVOICE::control::volume
 {
-    enum control : unsigned char {
+    enum control : uchar {
         enableVoice = 0,
         volume,
         velocitySense,
@@ -832,7 +843,7 @@ namespace ADDVOICE // usage ADDVOICE::control::volume
 
 namespace SUBSYNTH // usage SUBSYNTH::control::volume
 {
-    enum control : unsigned char {
+    enum control : uchar {
         volume = 0,
         velocitySense,
         panning,
@@ -870,7 +881,7 @@ namespace SUBSYNTH // usage SUBSYNTH::control::volume
 
 namespace PADSYNTH // usage PADSYNTH::control::volume
 {
-    enum control : unsigned char {
+    enum control : uchar {
         volume = 0,
         velocitySense,
         panning,
@@ -934,7 +945,7 @@ namespace PADSYNTH // usage PADSYNTH::control::volume
 
 namespace OSCILLATOR // usage OSCILLATOR::control::phaseRandomness
 {
-    enum control : unsigned char {
+    enum control : uchar {
         phaseRandomness = 0,
         magType, // Linear, -40dB, -60dB, -80dB, -100dB
         harmonicAmplitudeRandomness,
@@ -975,7 +986,7 @@ namespace OSCILLATOR // usage OSCILLATOR::control::phaseRandomness
         clearHarmonics = 96,
         convertToSine
     };
-    enum wave : unsigned char {
+    enum wave : uchar {
         sine = 0,
         triangle,
         pulse,
@@ -999,7 +1010,7 @@ namespace OSCILLATOR // usage OSCILLATOR::control::phaseRandomness
 
 namespace RESONANCE // usage RESONANCE::control::maxDb
 {
-    enum control : unsigned char {
+    enum control : uchar {
         enableResonance = 0,
         maxDb,
         centerFrequency,
@@ -1016,7 +1027,7 @@ namespace RESONANCE // usage RESONANCE::control::maxDb
 
 namespace LFOINSERT // usage LFOINSERT::control::speed
 {
-    enum control : unsigned char {
+    enum control : uchar {
         speed = 0,
         depth,
         delay,
@@ -1032,7 +1043,7 @@ namespace LFOINSERT // usage LFOINSERT::control::speed
 
 namespace FILTERINSERT // usage FILTERINSERT::control::centerFrequency
 {
-    enum control : unsigned char {
+    enum control : uchar {
         centerFrequency = 0,
         Q,
         frequencyTracking,
@@ -1064,7 +1075,7 @@ namespace FILTERINSERT // usage FILTERINSERT::control::centerFrequency
 
 namespace ENVELOPEINSERT // usage ENVELOPEINSERT::control::attackLevel
 {
-    enum control : unsigned char {
+    enum control : uchar {
         attackLevel = 0,
         attackTime,
         decayLevel,
@@ -1085,7 +1096,7 @@ namespace ENVELOPEINSERT // usage ENVELOPEINSERT::control::attackLevel
 
 namespace EFFECT // usage EFFECT::control::level
 {
-    enum control : unsigned char {
+    enum control : uchar {
         level = 0, // volume, wet/dry, gain for EQ
         panning, // band for EQ
         frequency, // time reverb, delay echo, L/R-mix dist, Not EQ
@@ -1096,7 +1107,7 @@ namespace EFFECT // usage EFFECT::control::level
         changed = 129 // not EQ
     };
 
-    enum sysIns : unsigned char {
+    enum sysIns : uchar {
         toEffect1 = 1, // system only
         toEffect2, // system only
         toEffect3, // system only
@@ -1106,7 +1117,7 @@ namespace EFFECT // usage EFFECT::control::level
         effectEnable // system only
     };
 
-    enum type : unsigned char { // sits above part kits
+    enum type : uchar { // sits above part kits
         none = NUM_KIT_ITEMS, // must not be moved
         reverb,
         echo,
@@ -1127,18 +1138,18 @@ namespace EFFECT // usage EFFECT::control::level
 union CommandBlock{
     struct{
         float value;
-        unsigned char type;
-        unsigned char source;
-        unsigned char control;
-        unsigned char part;
-        unsigned char kit;
-        unsigned char engine;
-        unsigned char insert;
-        unsigned char parameter;
-        unsigned char offset;
-        unsigned char miscmsg;
-        unsigned char spare1;
-        unsigned char spare0;
+        uchar type;
+        uchar source;
+        uchar control;
+        uchar part;
+        uchar kit;
+        uchar engine;
+        uchar insert;
+        uchar parameter;
+        uchar offset;
+        uchar miscmsg;
+        uchar spare1;
+        uchar spare0;
     } data;
     char bytes [sizeof(data)];
 };
